@@ -2,6 +2,7 @@
 
 from requests.utils import unquote, urlparse
 
+"""known keys in query section of encoded URL"""
 QUERY_KEYS = ["a", "c", "typo"]
 
 
@@ -40,6 +41,16 @@ def _decode(encoded_url):
     return query
 
 
-def decode(encoded_url):
-    """return decoded linkprotect url"""
+def decode(encoded_url: str) -> str:
+    """decode a linkprotect url
+
+    Args:
+      encoded_url: a linkprotect-encoded URL
+
+    Returns:
+      The original URL from the message source
+
+    Raises:
+      ValueError: if encoded_url has an unexpected format or parsing fails
+    """
     return _decode(encoded_url)["a"]
